---
layout: default
title: {{ site.name }}
pdf: true
permalink: /
---

<script>
    document.location = "https://sci-f.github.io"
</script>

<div>
    <img src="img/logo/scif-slash-green.png" width="300px" style="float:left">
    <h1 style="margin-top:10px">Scientific Filesystem</h1>
</div><br><br>

This is the official client for the Scientific Filesystem. If the page doesn't automatically redirect, please see the [documentaiton for SCIF here](https://sci-f.github.io/).
